yakumo.mapper

Package yakumo :: Module mapper |
[hide private]
[frames] | no frames]

# Module mapper

source code

Mapper classes

Classes | [hide private]
| NoopClass
| IntStrClass
| StrIntClass
| FloatStrClass
| BoolStrClass
| JSONClass
| Base64
| DateTimeClass
| Simple
| Resource
| List
| Dict

Functions | [hide private]
make_mappings(source, to_json, to_attr) | source code

Variables | [hide private]
| Noop = `NoopClass()`
| IntStr = `IntStrClass()`
| StrInt = `StrIntClass()`
| FloatStr = `FloatStrClass()`
| BoolStr = `BoolStrClass()`
| JSON = `JSONClass()`
| DateTime = `DateTimeClass()`
| __package__ = ``'``yakumo``'``